@@ -1,3 +1,4 @@
+from django.utils.encoding import escape_uri_path
 from rest_framework.response import Response
 
 
@@ -20,7 +21,7 @@ class XLSXFileMixin(object):
         Return the response with the proper content disposition and the customized
         filename instead of the browser default (or lack thereof).
         """
-        response = super(XLSXFileMixin, self).finalize_response(
+        response = super().finalize_response(
             request, response, *args, **kwargs
         )
         if (
@@ -28,6 +29,6 @@ class XLSXFileMixin(object):
             and response.accepted_renderer.format == "xlsx"
         ):
             response["content-disposition"] = "attachment; filename={}".format(
-                self.get_filename(request=request, *args, **kwargs),
+                escape_uri_path(self.get_filename(request=request, *args, **kwargs)),
             )
         return response
